@@ -48,7 +48,7 @@ from sqlalchemy.orm.query import Query as _SAQuery, _QueryEntity
 from sqlalchemy.orm.attributes import QueryableAttribute
 
 
-__version__ = '0.2.3'
+__version__ = '0.2.4'
 
 _PY3 = sys.version_info[0] == 3
 
@@ -769,9 +769,13 @@ def define(func):
         '/p1-foo-product.html'
 
     """
-    spec = inspect.getargspec(func)
-    assert not spec.varargs and not spec.keywords,\
-        'Variable args are not supported'
+    vargs_err = 'Variable args are not supported'
+    if _PY3:
+        spec = inspect.getfullargspec(func)
+        assert not spec.varargs and not spec.varkw, vargs_err
+    else:
+        spec = inspect.getargspec(func)
+        assert not spec.varargs and not spec.keywords, vargs_err
 
     signature = inspect.formatargspec(
         args=spec.args,
